"POI" SimpleBot plugin
======================

.. image:: https://img.shields.io/pypi/v/simplebot_poi.svg
   :target: https://pypi.org/project/simplebot_poi

.. image:: https://img.shields.io/pypi/pyversions/simplebot_poi.svg
   :target: https://pypi.org/project/simplebot_poi

.. image:: https://pepy.tech/badge/simplebot_poi
   :target: https://pepy.tech/project/simplebot_poi

.. image:: https://img.shields.io/pypi/l/simplebot_poi.svg
   :target: https://pypi.org/project/simplebot_poi

.. image:: https://github.com/simplebot-org/simplebot_poi/actions/workflows/python-ci.yml/badge.svg
   :target: https://github.com/simplebot-org/simplebot_poi/actions/workflows/python-ci.yml

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black

A `SimpleBot`_ plugin that detect messages (sent in private or in groups) with map coordinates and reply with a picture of that point in the map.

Install
-------

To install run::

  pip install simplebot-poi

Once installed send to the bot a message like: `geo: 46.012022036233546,9.29286152010328`


.. _SimpleBot: https://github.com/simplebot-org/simplebot
